CREATE OR REPLACE PROCEDURE CONSISTE_PEDIDO (
       P_CDFILIAL  IN  ITEMPEDIDO.CDFILIAL%TYPE,
       P_NRPEDIDO  IN  ITEMPEDIDO.NRPEDIDO%TYPE  DEFAULT NULL,
       P_NRITEMPED IN  ITEMPEDIDO.NRITEMPED%TYPE DEFAULT NULL,
       P_CDCLIENTE IN  CLIENTE.CDCLIENTE%TYPE DEFAULT NULL,
       P_TXMENSAGEM OUT  VARCHAR2,
       P_PEDIDOOK   OUT  VARCHAR2)
IS
   V_DIASEMANA    VARCHAR2(1);
   V_DTINICIAL    DATE;
   V_CTPED        NUMBER;
   V_CTNOTA       NUMBER;
   V_CTCLIE       NUMBER;
   V_CDCLIENTE    CLIENTE.CDCLIENTE%TYPE;
   V_CDPRODUTO    PRODUTO.CDPRODUTO%TYPE;
   V_NRINCONSPED  INCONSPEDIDO.NRINCONSPED%TYPE;
   V_SGESTADO     MUNICIPIO.SGESTADO%TYPE;
   V_NMMUNICIPIO  MUNICIPIO.NMMUNICIPIO%TYPE;
   V_IDINCONSLIB  CHAR;
BEGIN
/* P_PEDIDOOK
   A - OK
   B - INCONSISTENTE
*/
   P_PEDIDOOK   := 'A' ;
   P_TXMENSAGEM := '';
   FOR C_CONS IN
     (SELECT CDCONSPEDIDO, NMCONSPEDIDO
      FROM CONSPEDIDO
      WHERE DTIMPCONSPED <= SYSDATE
        AND IDCONPEDATIV = 'S'
      ORDER BY CDCONSPEDIDO) LOOP

      IF P_NRPEDIDO IS NOT NULL THEN
         /********************************************************/
         /*    PEDIDOS EM DUPLICIDADE POR CLIENTE PRODUTO     */
         /********************************************************/
         IF C_CONS.CDCONSPEDIDO = '001' THEN
            /* DEFINICAO DO PERIODO PARA PESQUISA GENERICA
               Se o dia atual for sexta feira: o periodo sera do dia atual ate a (ULTIMA) sexta feira
               se nao sera: do dia atual ate a (PENULTIMA) sexta feira */
            V_DIASEMANA := TO_CHAR(SYSDATE, 'D');
            IF V_DIASEMANA IN ('6', '7') THEN
               IF V_DIASEMANA = '6' THEN
                  V_DTINICIAL := SYSDATE - 7;
               ELSE
                  V_DTINICIAL := SYSDATE - 8;
               END IF;
            ELSE
               V_DTINICIAL := (SYSDATE + (6 - TO_NUMBER(TO_CHAR(SYSDATE, 'D')))) - 14;
            END IF;

            SELECT CDCLIENTE INTO V_CDCLIENTE
            FROM PEDIDO
            WHERE CDFILIAL = P_CDFILIAL
              AND NRPEDIDO = P_NRPEDIDO;

            IF P_NRITEMPED IS NULL THEN
               FOR C_ITEM IN
                 (SELECT NRITEMPED, CDPRODUTO
                  FROM ITEMPEDIDO
                  WHERE CDFILIAL  = P_CDFILIAL
                    AND NRPEDIDO  = P_NRPEDIDO) LOOP

                  SELECT COUNT(*) INTO V_CTPED
                  FROM PEDIDO PE, ITEMPEDIDO IT
                  WHERE PE.CDFILIAL  = P_CDFILIAL
                    AND PE.DTPEDIDO BETWEEN V_DTINICIAL AND SYSDATE
                    AND PE.CDCLIENTE = V_CDCLIENTE
                    AND PE.IDSITPEDIDO IN ('1', '2')
                    AND IT.CDFILIAL  = PE.CDFILIAL
                    AND IT.NRPEDIDO  = PE.NRPEDIDO
                    AND IT.CDPRODUTO = C_ITEM.CDPRODUTO
                    AND IT.NRPEDIDO <> P_NRPEDIDO;

                  IF V_CTPED > 0 THEN
                     GRAVA_INCONSPEDIDO(P_CDFILIAL, P_NRPEDIDO, C_ITEM.NRITEMPED, C_CONS.CDCONSPEDIDO, V_IDINCONSLIB);
                     IF V_IDINCONSLIB <> 'L' THEN
                        P_PEDIDOOK := 'B';
                     END IF;
                  END IF;
               END LOOP;
            ELSE
               SELECT CDPRODUTO INTO V_CDPRODUTO
               FROM ITEMPEDIDO
               WHERE CDFILIAL  = P_CDFILIAL
                 AND NRPEDIDO  = P_NRPEDIDO
                 AND NRITEMPED = P_NRITEMPED;

               SELECT COUNT(*) INTO V_CTPED
               FROM PEDIDO PE, ITEMPEDIDO IT
               WHERE PE.CDFILIAL  = P_CDFILIAL
                 AND PE.DTPEDIDO BETWEEN V_DTINICIAL AND SYSDATE
                 AND PE.CDCLIENTE = V_CDCLIENTE
                 AND PE.IDSITPEDIDO IN ('1', '2')
                 AND IT.CDFILIAL  = PE.CDFILIAL
                 AND IT.NRPEDIDO  = PE.NRPEDIDO
                 AND IT.CDPRODUTO = V_CDPRODUTO;

               IF V_CTPED > 0 THEN
                  GRAVA_INCONSPEDIDO(P_CDFILIAL, P_NRPEDIDO, P_NRITEMPED, C_CONS.CDCONSPEDIDO, V_IDINCONSLIB);
                  IF V_IDINCONSLIB <> 'L' THEN
                     P_PEDIDOOK := 'B';
                  END IF;
               END IF;
            END IF;
         END IF;
      END IF;

      IF P_CDCLIENTE IS NOT NULL THEN
         /********************************************************/
         /*****  Mensagem de Primeira Compra na Aprovao ********/
         /********************************************************/
         IF C_CONS.CDCONSPEDIDO = '002' THEN
            /* Verifica se  a primeira compra do cliente e manda a mensagem na aprovao */
            SELECT COUNT(*) INTO V_CTNOTA
            FROM NOTAFISCAL N, TIPOOPERAC T
            WHERE N.CDCLIENTE    = P_CDCLIENTE
              AND N.IDENTRSAIDOP = 'S'
              AND T.CDTIPOOPER   = N.CDTIPOOPER
              AND T.IDENTRSAIDOP = N.IDENTRSAIDOP;

            IF V_CTNOTA = 0 THEN
               P_TXMENSAGEM := P_TXMENSAGEM || 'Primeira compra do cliente._';
               IF P_PEDIDOOK = 'A' THEN
                  P_PEDIDOOK := 'C';
               END IF;
            END IF;
         END IF;

         /********************************************************/
         /****** Cliente  fora do estado de Minas Gerais ********/
         /********************************************************/
         IF C_CONS.CDCONSPEDIDO = '003' THEN
            SELECT COUNT(*) INTO V_CTCLIE
            FROM ENDECLIE E
            WHERE E.CDCLIENTE    = P_CDCLIENTE
              AND E.IDTPENDECLIE = 'T'
              AND E.SGESTADO     <> 'MG';

            IF V_CTCLIE > 0 THEN
               SELECT M.SGESTADO, M.NMMUNICIPIO
               INTO   V_SGESTADO, V_NMMUNICIPIO
               FROM ENDECLIE E, MUNICIPIO M
               WHERE E.CDCLIENTE    = P_CDCLIENTE
                 AND E.IDTPENDECLIE = 'T'
                 AND M.CDPAIS       = E.CDPAIS
                 AND M.SGESTADO     = E.SGESTADO
                 AND M.CDMUNICIPIO  = E.CDMUNICIPIO
                 AND M.SGESTADO     <> 'MG';

               P_TXMENSAGEM := P_TXMENSAGEM || 'Entrega solicitada para o estado de [' || V_SGESTADO || '] - [' || V_NMMUNICIPIO || ']_';
               IF P_PEDIDOOK = 'A' THEN
                  P_PEDIDOOK := 'D';
               END IF;
            END IF;
         END IF;
      END IF;
   END LOOP;
END;
/



-- VERSAO --
BEGIN ATUVEROBJ('CONSISTE_PEDIDO','4.05.125'); END;
/

