/* Tabela ENDEFORN: Endereo do Fornecedor*/
/* Descrio: A trigger insere registros na tabela ALTERAPARTSPED a partir de alteraes
na tabela ENDEFORN */
/* Objetivo: Registrar as alteraes realizadas nos campos CDPAIS, CDMUNICIPIO, DSENDEFORN, DSCOMPENDFOR, CDBAIRRO 
da tabela ENDEFORN, para serem utilizadas na gerao do registro 0175 do Sped Fiscal */

create or replace
TRIGGER ALTERA_END_FORN_SPED
AFTER UPDATE
ON ENDEFORN FOR EACH ROW
DECLARE  
  V_NRSEQALTPARTSPED NUMBER;
  V_DTOPER           DATE;
  V_CDMUNICIBGE      VARCHAR2(10);
  V_CDPAISBACEN      VARCHAR2(10);
BEGIN
  IF UPDATING THEN 
    IF (((:OLD.CDPAIS <> :NEW.CDPAIS) OR (:NEW.CDPAIS IS NULL)) AND (:OLD.CDPAIS IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;

       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;
       
       BEGIN
            SELECT CDPAISBACEN
              INTO V_CDPAISBACEN
              FROM PAIS
             WHERE CDPAIS = :OLD.CDPAIS;
       EXCEPTION 
            WHEN NO_DATA_FOUND THEN
                 V_CDPAISBACEN := NULL;
       END;    

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'F'||:OLD.CDFORNECED
               AND CDCAMPO = '04'
               AND DTALTERACAO < V_DTOPER;
       END;
       
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'F'||:OLD.CDFORNECED,'04',V_DTOPER,V_CDPAISBACEN);
    END IF;
    
    IF (((:OLD.CDMUNICIPIO <> :NEW.CDMUNICIPIO) OR (:NEW.CDMUNICIPIO IS NULL)) AND (:OLD.CDMUNICIPIO IS NOT NULL))THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;
       
       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;
       
       BEGIN
            SELECT CDMUNICIBGE
              INTO V_CDMUNICIBGE
              FROM MUNICIPIO
             WHERE CDMUNICIPIO = :OLD.CDMUNICIPIO
               AND CDPAIS      = :OLD.CDPAIS
               AND SGESTADO    = :OLD.SGESTADO;
       EXCEPTION 
            WHEN NO_DATA_FOUND THEN
                 V_CDMUNICIBGE := NULL;
       END;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'F'||:OLD.CDFORNECED
               AND CDCAMPO = '08'
               AND DTALTERACAO < V_DTOPER;
       END;
       
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'F'||:OLD.CDFORNECED,'08',V_DTOPER,V_CDMUNICIBGE);    
    END IF;
    
    IF (((:OLD.DSENDEFORN <> :NEW.DSENDEFORN) OR (:NEW.DSENDEFORN IS NULL)) AND (:OLD.DSENDEFORN IS NOT NULL))THEN
       
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;
       
       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'F'||:OLD.CDFORNECED
               AND CDCAMPO = '10'
               AND DTALTERACAO < V_DTOPER;
       END;
       
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'F'||:OLD.CDFORNECED,'10',V_DTOPER,:OLD.DSENDEFORN);    
    END IF;

    IF (((:OLD.DSCOMPENDFOR <> :NEW.DSCOMPENDFOR) OR (:NEW.DSCOMPENDFOR IS NULL)) AND (:OLD.DSCOMPENDFOR IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;

       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'F'||:OLD.CDFORNECED
               AND CDCAMPO = '12'
               AND DTALTERACAO < V_DTOPER;
       END;

       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT)
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'F'||:OLD.CDFORNECED,'12',V_DTOPER,:OLD.DSCOMPENDFOR);    
    END IF;
    
    IF (((:OLD.NMBAIRFORN <> :NEW.NMBAIRFORN) OR (:NEW.NMBAIRFORN IS NULL)) AND (:OLD.NMBAIRFORN IS NOT NULL))THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;

       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'F'||:OLD.CDFORNECED
               AND CDCAMPO = '13'
               AND DTALTERACAO < V_DTOPER;
       END;

       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT)
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'F'||:OLD.CDFORNECED,'13',V_DTOPER,:OLD.NMBAIRFORN);    
    END IF;
  END IF;
END;
/
-- VERSAO --
BEGIN ATUVEROBJ('ALTERA_END_FORN_SPED','5.85.000'); END;
/